@@ -1,5 +1,5 @@
 package Games::ABC_Path::Solver::Board;
-$Games::ABC_Path::Solver::Board::VERSION = '0.6.1';
+$Games::ABC_Path::Solver::Board::VERSION = '0.6.2';
 use warnings;
 use strict;
 
@@ -22,19 +22,19 @@ use Games::ABC_Path::Solver::Coord;
 
 use Scalar::Util qw(blessed);
 
-my $ABCP_VERDICT_NO = 0;
+my $ABCP_VERDICT_NO    = 0;
 my $ABCP_VERDICT_MAYBE = 1;
-my $ABCP_VERDICT_YES = 2;
+my $ABCP_VERDICT_YES   = 2;
 
-my %letters_map = (map { $letters[$_] => $_ } (0 .. $ABCP_MAX_LETTER));
+my %letters_map = ( map { $letters[$_] => $_ } ( 0 .. $ABCP_MAX_LETTER ) );
 
 sub _get_letter_numeric
 {
-    my ($self, $letter_ascii) = @_;
+    my ( $self, $letter_ascii ) = @_;
 
     my $index = $letters_map{$letter_ascii};
 
-    if (!defined ($index))
+    if ( !defined($index) )
     {
         confess "Unknown letter '$letter_ascii'";
     }
@@ -42,46 +42,53 @@ sub _get_letter_numeric
     return $index;
 }
 
-sub _iter_changed {
+sub _iter_changed
+{
     my $self = shift;
 
-    if (@_) {
+    if (@_)
+    {
         $self->{_iter_changed} = shift;
     }
 
     return $self->{_iter_changed};
 }
 
-sub _moves {
+sub _moves
+{
     my $self = shift;
 
-    if (@_) {
+    if (@_)
+    {
         $self->{_moves} = shift;
     }
 
     return $self->{_moves};
 }
 
-sub _error {
+sub _error
+{
     my $self = shift;
 
-    if (@_) {
+    if (@_)
+    {
         $self->{_error} = shift;
     }
 
     return $self->{_error};
 }
 
-
-sub _inc_changed {
+sub _inc_changed
+{
     my ($self) = @_;
 
-    $self->_iter_changed($self->_iter_changed+1);
+    $self->_iter_changed( $self->_iter_changed + 1 );
 
     return;
 }
 
-sub _flush_changed {
+sub _flush_changed
+{
     my ($self) = @_;
 
     my $ret = $self->_iter_changed;
@@ -91,10 +98,11 @@ sub _flush_changed {
     return $ret;
 }
 
-sub _add_move {
-    my ($self, $move) = @_;
+sub _add_move
+{
+    my ( $self, $move ) = @_;
 
-    push @{$self->_moves()}, $move;
+    push @{ $self->_moves() }, $move;
 
     $self->_inc_changed;
 
@@ -102,27 +110,31 @@ sub _add_move {
 }
 
 
-sub get_successful_layouts {
+sub get_successful_layouts
+{
     my ($self) = @_;
 
-    return [@{$self->_successful_layouts}];
+    return [ @{ $self->_successful_layouts } ];
 }
 
-sub _successful_layouts {
+sub _successful_layouts
+{
     my $self = shift;
 
-    if (@_) {
+    if (@_)
+    {
         $self->{_successful_layouts} = shift;
     }
 
     return $self->{_successful_layouts};
 }
 
-
-sub _layout {
+sub _layout
+{
     my $self = shift;
 
-    if (@_) {
+    if (@_)
+    {
         $self->{_layout} = shift;
     }
 
@@ -132,23 +144,23 @@ sub _layout {
 # The letter indexes.
 sub _l_indexes
 {
-    return (0 .. $ABCP_MAX_LETTER);
+    return ( 0 .. $ABCP_MAX_LETTER );
 }
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $layout_string = $args->{layout};
 
-    if (!defined($layout_string))
+    if ( !defined($layout_string) )
     {
         $layout_string = '';
     }
 
-    $self->_layout(\$layout_string);
-    $self->_successful_layouts([]);
-    $self->_moves([]);
+    $self->_layout( \$layout_string );
+    $self->_successful_layouts( [] );
+    $self->_moves( [] );
     $self->_iter_changed(0);
 
     return;
@@ -156,80 +168,76 @@ sub _init
 
 sub _calc_offset
 {
-    my ($self, $letter, $xy) = @_;
+    my ( $self, $letter, $xy ) = @_;
 
-    if (($letter < 0) or ($letter >= 25))
+    if ( ( $letter < 0 ) or ( $letter >= 25 ) )
     {
         confess "Letter $letter out of range.";
     }
 
-    return $letter * $BOARD_SIZE + $self->_xy_to_int([$xy->y, $xy->x]);
+    return $letter * $BOARD_SIZE + $self->_xy_to_int( [ $xy->y, $xy->x ] );
 }
 
 sub _get_verdict
 {
-    my ($self, $letter, $xy) = @_;
+    my ( $self, $letter, $xy ) = @_;
 
-    return vec(
-        ${$self->_layout},
-        $self->_calc_offset($letter, $xy,),
-        2
-    );
+    return vec( ${ $self->_layout }, $self->_calc_offset( $letter, $xy, ), 2 );
 }
 
 sub _set_verdict
 {
-    my ($self, $letter, $xy, $verdict) = @_;
+    my ( $self, $letter, $xy, $verdict ) = @_;
 
     # Temporary - remove later.
-    if (@_ != 4)
+    if ( @_ != 4 )
     {
         confess "_set_verdict has wrong number of args.";
     }
 
-    if (not
-        (($verdict == $ABCP_VERDICT_NO)
-        || ($verdict == $ABCP_VERDICT_MAYBE)
-        || ($verdict == $ABCP_VERDICT_YES))
-    )
+    if (
+        not(   ( $verdict == $ABCP_VERDICT_NO )
+            || ( $verdict == $ABCP_VERDICT_MAYBE )
+            || ( $verdict == $ABCP_VERDICT_YES ) )
+        )
     {
         confess "Invalid verdict $verdict .";
     }
 
-    vec(${$self->_layout}, $self->_calc_offset($letter, $xy), 2)
-        = $verdict;
+    vec( ${ $self->_layout }, $self->_calc_offset( $letter, $xy ), 2 ) =
+        $verdict;
 
     return;
 }
 
 sub _xy_loop
 {
-    my ($self, $sub_ref) = (@_);
+    my ( $self, $sub_ref ) = (@_);
 
-    foreach my $y ($self->_y_indexes)
+    foreach my $y ( $self->_y_indexes )
     {
-        if ($self->_error())
+        if ( $self->_error() )
         {
             return;
         }
-        foreach my $x ($self->_x_indexes)
+        foreach my $x ( $self->_x_indexes )
         {
-            if ($self->_error())
+            if ( $self->_error() )
             {
                 return;
             }
-            $sub_ref->(Games::ABC_Path::Solver::Coord->new({x => $x, y => $y}));
+            $sub_ref->(
+                Games::ABC_Path::Solver::Coord->new( { x => $x, y => $y } ) );
         }
     }
     return;
 }
 
-
 sub _set_verdicts_for_letter_sets
 {
-    my ($self, $letter_list, $maybe_list) = @_;
+    my ( $self, $letter_list, $maybe_list ) = @_;
 
-    my %cell_is_maybe = (map { $_->_to_s() => 1 } @$maybe_list);
+    my %cell_is_maybe = ( map { $_->_to_s() => 1 } @$maybe_list );
 
     foreach my $letter_ascii (@$letter_list)
     {
@@ -239,8 +247,10 @@ sub _set_verdicts_for_letter_sets
             sub {
                 my ($xy) = @_;
 
-                $self->_set_verdict($letter, $xy,
-                    ((exists $cell_is_maybe{$xy->_to_s()})
+                $self->_set_verdict(
+                    $letter, $xy,
+                    (
+                        ( exists $cell_is_maybe{ $xy->_to_s() } )
                         ? $ABCP_VERDICT_MAYBE
                         : $ABCP_VERDICT_NO
                     )
@@ -254,13 +264,16 @@ sub _set_verdicts_for_letter_sets
 
 sub _set_conclusive_verdict_for_letter
 {
-    my ($self, $letter, $l_xy) = @_;
+    my ( $self, $letter, $l_xy ) = @_;
 
-    $self->_xy_loop(sub {
+    $self->_xy_loop(
+        sub {
             my ($xy) = @_;
 
-            $self->_set_verdict($letter, $xy,
-                ($l_xy->_equal($xy)
+            $self->_set_verdict(
+                $letter, $xy,
+                (
+                      $l_xy->_equal($xy)
                     ? $ABCP_VERDICT_YES
                     : $ABCP_VERDICT_NO
                 )
@@ -268,14 +281,14 @@ sub _set_conclusive_verdict_for_letter
         }
     );
 
-    OTHER_LETTER:
-    foreach my $other_letter ($self->_l_indexes)
+OTHER_LETTER:
+    foreach my $other_letter ( $self->_l_indexes )
     {
-        if ($other_letter == $letter)
+        if ( $other_letter == $letter )
         {
             next OTHER_LETTER;
         }
-        $self->_set_verdict($other_letter, $l_xy, $ABCP_VERDICT_NO);
+        $self->_set_verdict( $other_letter, $l_xy, $ABCP_VERDICT_NO );
     }
 
     return;
@@ -283,133 +296,145 @@ sub _set_conclusive_verdict_for_letter
 
 sub _get_possible_letter_indexes
 {
-    my ($self, $xy) = @_;
+    my ( $self, $xy ) = @_;
 
-    return
-    [
-        grep { $self->_get_verdict($_, $xy) != $ABCP_VERDICT_NO }
-        $self->_l_indexes()
-    ];
+    return [ grep { $self->_get_verdict( $_, $xy ) != $ABCP_VERDICT_NO }
+            $self->_l_indexes() ];
 }
 
 
 sub get_possible_letters_for_cell
 {
-    my ($self, $x, $y) = @_;
+    my ( $self, $x, $y ) = @_;
 
-    return [@letters[@{$self->_get_possible_letter_indexes(Games::ABC_Path::Solver::Coord->new({x => $x, y => $y}))}]];
+    return [
+        @letters[
+            @{
+                $self->_get_possible_letter_indexes(
+                    Games::ABC_Path::Solver::Coord->new( { x => $x, y => $y } )
+                )
+            }
+        ]
+    ];
 }
 
 sub _get_possible_letters_string
 {
-    my ($self, $xy) = @_;
+    my ( $self, $xy ) = @_;
 
-    return join(',', @{$self->get_possible_letters_for_cell($xy->x, $xy->y)});
+    return
+        join( ',',
+        @{ $self->get_possible_letters_for_cell( $xy->x, $xy->y ) } );
 }
 
-
 sub _infer_letters
 {
     my ($self) = @_;
 
-    foreach my $letter ($self->_l_indexes)
+    foreach my $letter ( $self->_l_indexes )
     {
         my @true_cells;
 
-        $self->_xy_loop(sub {
-            my ($xy) = @_;
+        $self->_xy_loop(
+            sub {
+                my ($xy) = @_;
 
-            my $ver = $self->_get_verdict($letter, $xy);
-            if (    ($ver == $ABCP_VERDICT_YES)
-                || ($ver == $ABCP_VERDICT_MAYBE))
-            {
-                push @true_cells, $xy;
+                my $ver = $self->_get_verdict( $letter, $xy );
+                if (   ( $ver == $ABCP_VERDICT_YES )
+                    || ( $ver == $ABCP_VERDICT_MAYBE ) )
+                {
+                    push @true_cells, $xy;
+                }
             }
-        });
+        );
 
-        if (! @true_cells)
+        if ( !@true_cells )
         {
-            $self->_error(['letter', $letter]);
+            $self->_error( [ 'letter', $letter ] );
             return;
         }
-        elsif (@true_cells == 1)
+        elsif ( @true_cells == 1 )
         {
             my $xy = $true_cells[0];
-            if ($self->_get_verdict($letter, $xy) ==
-                $ABCP_VERDICT_MAYBE)
+            if ( $self->_get_verdict( $letter, $xy ) == $ABCP_VERDICT_MAYBE )
             {
-                $self->_set_conclusive_verdict_for_letter($letter, $xy);
+                $self->_set_conclusive_verdict_for_letter( $letter, $xy );
                 $self->_add_move(
-                    Games::ABC_Path::Solver::Move::LastRemainingCellForLetter->new(
+                    Games::ABC_Path::Solver::Move::LastRemainingCellForLetter
+                        ->new(
                         {
-                            vars =>
-                            {
+                            vars => {
                                 letter => $letter,
                                 coords => $xy,
                             },
                         }
-                    )
+                        )
                 );
             }
         }
 
-        my @neighbourhood = (map { [(0) x $LEN] } ($self->_y_indexes));
+        my @neighbourhood = ( map { [ (0) x $LEN ] } ( $self->_y_indexes ) );
 
         foreach my $true (@true_cells)
         {
-            foreach my $coords
-            (
+            foreach my $coords (
                 grep {
-                    $self->_x_in_range($_->[0]) and $self->_y_in_range($_->[1])
+                            $self->_x_in_range( $_->[0] )
+                        and $self->_y_in_range( $_->[1] )
                 }
-                map { [$true->x + $_->[0], $true->y + $_->[1]] }
-                map { my $d = $_; map { [$_, $d] } (-1 .. 1) }
-                (-1 .. 1)
-            )
+                map { [ $true->x + $_->[0], $true->y + $_->[1] ] }
+                map {
+                    my $d = $_;
+                    map { [ $_, $d ] } ( -1 .. 1 )
+                } ( -1 .. 1 )
+                )
             {
-                $neighbourhood[$coords->[1]][$coords->[0]] = 1;
+                $neighbourhood[ $coords->[1] ][ $coords->[0] ] = 1;
             }
         }
 
         foreach my $neighbour_letter (
-            (($letter > 0) ? ($letter-1) : ()),
-            (($letter < $ABCP_MAX_LETTER) ? ($letter+1) : ()),
-        )
+            ( ( $letter > 0 )                ? ( $letter - 1 ) : () ),
+            ( ( $letter < $ABCP_MAX_LETTER ) ? ( $letter + 1 ) : () ),
+            )
         {
-            $self->_xy_loop(sub {
-                my ($xy) = @_;
+            $self->_xy_loop(
+                sub {
+                    my ($xy) = @_;
 
-                if ($neighbourhood[$xy->y][$xy->x])
-                {
-                    return;
-                }
+                    if ( $neighbourhood[ $xy->y ][ $xy->x ] )
+                    {
+                        return;
+                    }
 
-                my $existing_verdict =
-                    $self->_get_verdict($neighbour_letter, $xy);
+                    my $existing_verdict =
+                        $self->_get_verdict( $neighbour_letter, $xy );
 
-                if ($existing_verdict == $ABCP_VERDICT_YES)
-                {
-                    $self->_error(['mismatched_verdict', $xy]);
-                    return;
-                }
+                    if ( $existing_verdict == $ABCP_VERDICT_YES )
+                    {
+                        $self->_error( [ 'mismatched_verdict', $xy ] );
+                        return;
+                    }
 
-                if ($existing_verdict == $ABCP_VERDICT_MAYBE)
-                {
-                    $self->_set_verdict($neighbour_letter, $xy, $ABCP_VERDICT_NO);
-                    $self->_add_move(
-                        Games::ABC_Path::Solver::Move::LettersNotInVicinity->new(
-                            {
-                                vars =>
+                    if ( $existing_verdict == $ABCP_VERDICT_MAYBE )
+                    {
+                        $self->_set_verdict( $neighbour_letter, $xy,
+                            $ABCP_VERDICT_NO );
+                        $self->_add_move(
+                            Games::ABC_Path::Solver::Move::LettersNotInVicinity
+                                ->new(
                                 {
-                                    target => $neighbour_letter,
-                                    coords => $xy,
-                                    source => $letter,
-                                },
-                            }
-                        )
-                    );
+                                    vars => {
+                                        target => $neighbour_letter,
+                                        coords => $xy,
+                                        source => $letter,
+                                    },
+                                }
+                                )
+                        );
+                    }
                 }
-            });
+            );
         }
     }
 
@@ -420,42 +445,44 @@ sub _infer_cells
 {
     my ($self) = @_;
 
-    $self->_xy_loop(sub {
-        my ($xy) = @_;
+    $self->_xy_loop(
+        sub {
+            my ($xy) = @_;
 
-        my $letters_aref = $self->_get_possible_letter_indexes($xy);
+            my $letters_aref = $self->_get_possible_letter_indexes($xy);
 
-        if (! @$letters_aref)
-        {
-            $self->_error(['cell', $xy]);
-            return;
-        }
-        elsif (@$letters_aref == 1)
-        {
-            my $letter = $letters_aref->[0];
-
-            if ($self->_get_verdict($letter, $xy) == $ABCP_VERDICT_MAYBE)
+            if ( !@$letters_aref )
             {
-                $self->_set_conclusive_verdict_for_letter($letter, $xy);
-                $self->_add_move(
-                    Games::ABC_Path::Solver::Move::LastRemainingLetterForCell->new(
-                        {
-                            vars =>
+                $self->_error( [ 'cell', $xy ] );
+                return;
+            }
+            elsif ( @$letters_aref == 1 )
+            {
+                my $letter = $letters_aref->[0];
+
+                if (
+                    $self->_get_verdict( $letter, $xy ) == $ABCP_VERDICT_MAYBE )
+                {
+                    $self->_set_conclusive_verdict_for_letter( $letter, $xy );
+                    $self->_add_move(
+                        Games::ABC_Path::Solver::Move::LastRemainingLetterForCell
+                            ->new(
                             {
-                                coords => $xy,
-                                letter => $letter,
+                                vars => {
+                                    coords => $xy,
+                                    letter => $letter,
+                                },
                             },
-                        },
-                    )
-                );
+                            )
+                    );
+                }
             }
         }
-    });
+    );
 
     return;
 }
 
-
 sub _inference_iteration
 {
     my ($self) = @_;
@@ -473,9 +500,9 @@ sub _neighbourhood_and_individuality_inferring
 
     my $num_changed = 0;
 
-    while (my $iter_changed = $self->_inference_iteration())
+    while ( my $iter_changed = $self->_inference_iteration() )
     {
-        if ($self->_error())
+        if ( $self->_error() )
         {
             return;
         }
@@ -489,12 +516,11 @@ sub _clone
 {
     my ($self) = @_;
 
-    return
-        ref($self)->new(
-            {
-                layout => ${$self->_layout()},
-            }
-        );
+    return ref($self)->new(
+        {
+            layout => ${ $self->_layout() },
+        }
+    );
 }
 
 
@@ -504,12 +530,14 @@ sub solve
 
     my $error = $self->_solve_wrapper;
 
-    return [map {
-        my $obj = $_;
-        (blessed($obj) && $obj->isa('Games::ABC_Path::Solver::Coord'))
-            ? ($obj->x, $obj->y)
-            : ($obj)
-        } @$error];
+    return [
+        map {
+            my $obj = $_;
+            ( blessed($obj) && $obj->isa('Games::ABC_Path::Solver::Coord') )
+                ? ( $obj->x, $obj->y )
+                : ($obj)
+        } @$error
+    ];
 }
 
 sub _solve_wrapper
@@ -518,7 +546,7 @@ sub _solve_wrapper
 
     $self->_neighbourhood_and_individuality_inferring;
 
-    if ($self->_error)
+    if ( $self->_error )
     {
         return $self->_error;
     }
@@ -526,28 +554,30 @@ sub _solve_wrapper
     my @min_coords;
     my @min_options;
 
-    $self->_xy_loop(sub {
-        my ($xy) = @_;
+    $self->_xy_loop(
+        sub {
+            my ($xy) = @_;
 
-        my $letters_aref = $self->_get_possible_letter_indexes($xy);
+            my $letters_aref = $self->_get_possible_letter_indexes($xy);
 
-        if (! @$letters_aref)
-        {
-            $self->_error(['cell', $xy]);
-        }
-        elsif (@$letters_aref > 1)
-        {
-            if ((!@min_coords) or (@$letters_aref < @min_options))
+            if ( !@$letters_aref )
             {
-                @min_options = @$letters_aref;
-                @min_coords = ($xy);
+                $self->_error( [ 'cell', $xy ] );
             }
+            elsif ( @$letters_aref > 1 )
+            {
+                if ( ( !@min_coords ) or ( @$letters_aref < @min_options ) )
+                {
+                    @min_options = @$letters_aref;
+                    @min_coords  = ($xy);
+                }
+            }
+
+            return;
         }
+    );
 
-        return;
-    });
-
-    if ($self->_error)
+    if ( $self->_error )
     {
         return $self->_error;
     }
@@ -555,6 +585,7 @@ sub _solve_wrapper
     if (@min_coords)
     {
         my ($xy) = @min_coords;
+
         # We have at least one multiple rank cell. Let's recurse there:
         foreach my $letter (@min_options)
         {
@@ -568,28 +599,25 @@ sub _solve_wrapper
                 ),
             );
 
-            $recurse_solver->_set_conclusive_verdict_for_letter(
-                $letter, $xy
-            );
+            $recurse_solver->_set_conclusive_verdict_for_letter( $letter, $xy );
 
             $recurse_solver->_solve_wrapper;
 
-            foreach my $move (@{ $recurse_solver->get_moves })
+            foreach my $move ( @{ $recurse_solver->get_moves } )
             {
-                $self->_add_move($move->bump());
+                $self->_add_move( $move->bump() );
             }
 
-            if ($recurse_solver->_error())
+            if ( $recurse_solver->_error() )
             {
                 $self->_add_move(
                     Games::ABC_Path::Solver::Move::ResultsInAnError->new(
-                    {
-                        vars =>
                         {
-                            letter => $letter,
-                            coords => $xy,
-                        },
-                    }
+                            vars => {
+                                letter => $letter,
+                                coords => $xy,
+                            },
+                        }
                     )
                 );
             }
@@ -598,21 +626,21 @@ sub _solve_wrapper
                 $self->_add_move(
                     Games::ABC_Path::Solver::Move::ResultsInASuccess->new(
                         {
-                            vars => { letter => $letter, coords => $xy,},
+                            vars => { letter => $letter, coords => $xy, },
                         }
                     )
                 );
-                push @{$self->_successful_layouts},
-                    @{$recurse_solver->get_successful_layouts()};
+                push @{ $self->_successful_layouts },
+                    @{ $recurse_solver->get_successful_layouts() };
             }
         }
 
-        my $count = @{$self->_successful_layouts()};
-        if (! $count)
+        my $count = @{ $self->_successful_layouts() };
+        if ( !$count )
         {
             return ['all_options_bad'];
         }
-        elsif ($count == 1)
+        elsif ( $count == 1 )
         {
             return ['success'];
         }
@@ -623,25 +651,25 @@ sub _solve_wrapper
     }
     else
     {
-        $self->_successful_layouts([$self->_clone()]);
+        $self->_successful_layouts( [ $self->_clone() ] );
         return ['success'];
     }
 }
 
-my $letter_re_s = join('', map { quotemeta($_) } @letters);
-my $letter_re = qr{[$letter_re_s]};
+my $letter_re_s         = join( '', map { quotemeta($_) } @letters );
+my $letter_re           = qr{[$letter_re_s]};
 my $letter_and_space_re = qr{[ $letter_re_s]};
-my $top_bottom_re = qr/^${letter_re}{7}\n/ms;
+my $top_bottom_re       = qr/^${letter_re}{7}\n/ms;
 my $inner_re = qr/^${letter_re}${letter_and_space_re}{5}${letter_re}\n/ms;
 
 sub _assert_letters_appear_once
 {
-    my ($self, $layout_string) = @_;
+    my ( $self, $layout_string ) = @_;
 
-    my %count_letters = (map { $_ => 0 } @letters);
-    foreach my $letter ($layout_string =~ m{($letter_re)}g)
+    my %count_letters = ( map { $_ => 0 } @letters );
+    foreach my $letter ( $layout_string =~ m{($letter_re)}g )
     {
-        if ($count_letters{$letter}++)
+        if ( $count_letters{$letter}++ )
         {
             confess "Letter '$letter' encountered twice in the layout.";
         }
@@ -652,7 +680,7 @@ sub _assert_letters_appear_once
 
 sub _process_major_diagonal
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my @major_diagonal_letters;
 
@@ -666,9 +694,9 @@ sub _process_major_diagonal
 
     $self->_set_verdicts_for_letter_sets(
         \@major_diagonal_letters,
-        [map
-            { Games::ABC_Path::Solver::Coord->new({x => $_, y => $_}) }
-            $self->_y_indexes
+        [
+            map { Games::ABC_Path::Solver::Coord->new( { x => $_, y => $_ } ) }
+                $self->_y_indexes
         ],
     );
 
@@ -677,7 +705,7 @@ sub _process_major_diagonal
 
 sub _process_minor_diagonal
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my @minor_diagonal_letters;
 
@@ -691,7 +719,11 @@ sub _process_minor_diagonal
 
     $self->_set_verdicts_for_letter_sets(
         \@minor_diagonal_letters,
-        [map { Games::ABC_Path::Solver::Coord->new({x => $_, y => 4-$_}) } ($self->_y_indexes)]
+        [
+            map {
+                Games::ABC_Path::Solver::Coord->new( { x => $_, y => 4 - $_ } )
+            } ( $self->_y_indexes )
+        ]
     );
 
     return;
@@ -699,16 +731,22 @@ sub _process_minor_diagonal
 
 sub _process_input_columns
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    my $top_row = $args->{top};
+    my $top_row    = $args->{top};
     my $bottom_row = $args->{bottom};
 
-    foreach my $x ($self->_x_indexes)
+    foreach my $x ( $self->_x_indexes )
     {
         $self->_set_verdicts_for_letter_sets(
-            [substr($top_row, $x+1, 1), substr($bottom_row, $x+1, 1),],
-            [map { Games::ABC_Path::Solver::Coord->new({x =>$x, y => $_}) } $self->_y_indexes],
+            [
+                substr( $top_row, $x + 1, 1 ), substr( $bottom_row, $x + 1, 1 ),
+            ],
+            [
+                map {
+                    Games::ABC_Path::Solver::Coord->new( { x => $x, y => $_ } )
+                } $self->_y_indexes
+            ],
         );
     }
 
@@ -717,40 +755,44 @@ sub _process_input_columns
 
 sub _process_input_rows_and_initial_letter_clue
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $rows = $args->{rows};
 
-    my ($clue_x, $clue_y, $clue_letter);
+    my ( $clue_x, $clue_y, $clue_letter );
 
-    foreach my $y ($self->_y_indexes)
+    foreach my $y ( $self->_y_indexes )
     {
         my $row = $rows->[$y];
         $self->_set_verdicts_for_letter_sets(
-            [substr($row, 0, 1), substr($row, -1),],
-            [map { Games::ABC_Path::Solver::Coord->new({x => $_,y => $y}) } $self->_x_indexes],
+            [ substr( $row, 0, 1 ), substr( $row, -1 ), ],
+            [
+                map {
+                    Games::ABC_Path::Solver::Coord->new( { x => $_, y => $y } )
+                } $self->_x_indexes
+            ],
         );
 
-        my $s = substr($row, 1, -1);
-        if ($s =~ m{($letter_re)}g)
+        my $s = substr( $row, 1, -1 );
+        if ( $s =~ m{($letter_re)}g )
         {
-            my ($l, $x_plus_1) = ($1, pos($s));
-            if (defined($clue_letter))
+            my ( $l, $x_plus_1 ) = ( $1, pos($s) );
+            if ( defined($clue_letter) )
             {
                 confess "Found more than one clue letter in the layout!";
             }
-            ($clue_x, $clue_y, $clue_letter) = ($x_plus_1-1, $y, $l);
+            ( $clue_x, $clue_y, $clue_letter ) = ( $x_plus_1 - 1, $y, $l );
         }
     }
 
-    if (!defined ($clue_letter))
+    if ( !defined($clue_letter) )
     {
         confess "Did not find any clue letters inside the layout.";
     }
 
     $self->_set_conclusive_verdict_for_letter(
         $self->_get_letter_numeric($clue_letter),
-        Games::ABC_Path::Solver::Coord->new({x => $clue_x, y => $clue_y}),
+        Games::ABC_Path::Solver::Coord->new( { x => $clue_x, y => $clue_y } ),
     );
 
     return;
@@ -758,30 +800,31 @@ sub _process_input_rows_and_initial_letter_clue
 
 sub _input
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    if ($args->{version} ne 1)
+    if ( $args->{version} ne 1 )
     {
         die "Can only handle version 1";
     }
 
     my $layout_string = $args->{layout};
-    if ($layout_string !~ m/\A${top_bottom_re}${inner_re}{5}${top_bottom_re}\z/ms)
+    if ( $layout_string !~
+        m/\A${top_bottom_re}${inner_re}{5}${top_bottom_re}\z/ms )
     {
-        die "Invalid format. Should be Letter{7}\n(Letter{spaces or one letter}{5}Letter){5}\nLetter{7}";
+        die
+"Invalid format. Should be Letter{7}\n(Letter{spaces or one letter}{5}Letter){5}\nLetter{7}";
     }
 
-    my @rows = split(/\n/, $layout_string);
+    my @rows = split( /\n/, $layout_string );
 
-    my $top_row = shift(@rows);
+    my $top_row    = shift(@rows);
     my $bottom_row = pop(@rows);
 
     # Now let's process the layout string and populate the verdicts table.
     $self->_assert_letters_appear_once($layout_string);
 
     my $parse_context =
-        { top => $top_row, bottom => $bottom_row, rows => \@rows, }
-        ;
+        { top => $top_row, bottom => $bottom_row, rows => \@rows, };
 
     $self->_process_major_diagonal($parse_context);
 
@@ -791,7 +834,6 @@ sub _input
 
     $self->_process_input_rows_and_initial_letter_clue($parse_context);
 
-
     return;
 }
 
@@ -803,25 +845,27 @@ sub _get_results_text_table
         my $cols = shift;
 
         return
-            "| " .
-            join(
-                " | ",
-                map { length($_) == 1 ? "  $_  " : $_ } @$cols
-            ) . " |\n";
+              "| "
+            . join( " | ", map { length($_) == 1 ? "  $_  " : $_ } @$cols )
+            . " |\n";
     };
 
-    return join('',
-        map { $render_row->($_) }
-        (
-        [map { sprintf("X = %d", $_+1) } $self->_x_indexes ],
-        map { my $y = $_;
-            [
-                map
-                { $self->_get_possible_letters_string(Games::ABC_Path::Solver::Coord->new({x => $_, y => $y})) }
-                $self->_x_indexes
-            ]
-            }
-            $self->_y_indexes
+    return join(
+        '',
+        map { $render_row->($_) } (
+            [ map { sprintf( "X = %d", $_ + 1 ) } $self->_x_indexes ],
+            map {
+                my $y = $_;
+                [
+                    map {
+                        $self->_get_possible_letters_string(
+                            Games::ABC_Path::Solver::Coord->new(
+                                { x => $_, y => $y }
+                            )
+                        )
+                    } $self->_x_indexes
+                ]
+            } $self->_y_indexes
         )
     );
 }
@@ -831,13 +875,14 @@ sub get_successes_text_tables
 {
     my ($self) = @_;
 
-    return [map { $_->_get_results_text_table() } @{$self->get_successful_layouts()}];
+    return [ map { $_->_get_results_text_table() }
+            @{ $self->get_successful_layouts() } ];
 }
 
 
 sub input_from_file
 {
-    my ($class, $board_fn) = @_;
+    my ( $class, $board_fn ) = @_;
 
     open my $in_fh, "<", $board_fn
         or die "Cannot open '$board_fn' - $!";
@@ -846,15 +891,15 @@ sub input_from_file
     chomp($first_line);
 
     my $magic = 'ABC Path Solver Layout Version 1:';
-    if ($first_line !~ m{\A\Q$magic\E\s*\z})
+    if ( $first_line !~ m{\A\Q$magic\E\s*\z} )
     {
         die "Can only process files whose first line is '$magic'!";
     }
 
     my $layout_string = '';
-    foreach my $line_idx (1 .. 7)
+    foreach my $line_idx ( 1 .. 7 )
     {
-        chomp(my $line = <$in_fh>);
+        chomp( my $line = <$in_fh> );
         $layout_string .= "$line\n";
     }
     close($in_fh);
@@ -865,11 +910,11 @@ sub input_from_file
 
 sub input_from_v1_string
 {
-    my ($class, $layout_string) = @_;
+    my ( $class, $layout_string ) = @_;
 
     my $self = $class->new;
 
-    $self->_input({ layout => $layout_string, version => 1});
+    $self->_input( { layout => $layout_string, version => 1 } );
 
     return $self;
 }
@@ -879,11 +924,11 @@ sub get_moves
 {
     my ($self) = @_;
 
-    return [@{ $self->_moves }];
+    return [ @{ $self->_moves } ];
 }
 
 
-1; # End of Games::ABC_Path::Solver::Board
+1;    # End of Games::ABC_Path::Solver::Board
 
 __END__
 
@@ -897,7 +942,7 @@ Games::ABC_Path::Solver::Board - handles an ABC Path board.
 
 =head1 VERSION
 
-version 0.6.1
+version 0.6.2
 
 =head1 SYNOPSIS
 
@@ -921,10 +966,6 @@ version 0.6.1
         print +(' => ' x $move->get_depth()), $move->get_text(), "\n";
     }
 
-=head1 VERSION
-
-version 0.6.1
-
 =head1 FUNCTIONS
 
 =head2 new
@@ -982,101 +1023,10 @@ object of a L<Games::ABC_Path::Solver::Move> sub-class.
 
 Shlomi Fish, C<< <shlomif at cpan.org> >>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-games-abc_path-solver at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-ABC_Path-Solver>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-You can find documentation for this module with the perldoc command.
-
-    perldoc Games::ABC_Path::Solver::Board
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-ABC_Path-Solver>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Games-ABC_Path-Solver>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Games-ABC_Path-Solver>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Games-ABC_Path-Solver/>
-
-=back
-
-=head1 ACKNOWLEDGEMENTS
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2010 Shlomi Fish.
-
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
-
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
-
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
-
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2018 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/abc-path/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Games::ABC_Path::Solver::Board
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -1094,14 +1044,6 @@ L<https://metacpan.org/release/Games-ABC_Path-Solver>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Games-ABC_Path-Solver>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -1110,22 +1052,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-ABC_Path-Solver>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Games-ABC_Path-Solver>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Games-ABC_Path-Solver>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -1174,4 +1100,25 @@ L<https://github.com/shlomif/abc-path>
 
   git clone https://github.com/shlomif/abc-path
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/abc-path/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
